=== modified file 'NEWS'
--- NEWS	2005-10-13 01:43:44 +0000
+++ NEWS	2005-10-13 03:43:37 +0000
@@ -30,7 +30,7 @@
       related questions.
 
 
-bzr 0.1 2005-10-06
+bzr 0.1 2005-10-11
 
   NOTES:
 

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2005-10-10 04:30:52 +0000
+++ bzrlib/__init__.py	2005-10-11 04:13:47 +0000
@@ -39,7 +39,7 @@
 del locale
 
 __copyright__ = "Copyright 2005 Canonical Development Ltd."
-__version__ = '0.1rc2'
+__version__ = '0.1'
 
 
 def get_bzr_revision():

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2005-09-30 14:27:41 +0000
+++ bzrlib/annotate.py	2005-10-11 04:03:25 +0000
@@ -16,8 +16,17 @@
 
 """File annotate based on weave storage"""
 
+# TODO: Choice of more or less verbose formats:
+# 
+# short: just show revno
+# long: revno, author, date
+# interposed: show more details between blocks of modified lines
+
+# TODO: Show which revision caused a line to merge into the parent
+
 import sys
 import os
+import time
 
 import bzrlib.weave
 
@@ -25,29 +34,33 @@
     if to_file is None:
         to_file = sys.stdout
     rh = branch.revision_history()
-    w = branch.weave_store.get_weave(file_id)
+    w = branch.weave_store.get_weave(file_id, branch.get_transaction())
     last_origin = None
     for origin, text in w.annotate_iter(rev_id):
         text = text.rstrip('\r\n')
         if origin == last_origin:
-            print '      | %s' % (text)
+            print '         | %s' % (text)
         else:
             last_origin = origin
             line_rev_id = w.idx_to_name(origin)
-            try:
+            if line_rev_id in rh:
                 revno = rh.index(line_rev_id) + 1
-                print '%5d | %s' % (revno, text)
-            except ValueError:
-                print 'merge | %s' % (text)
+                print '%8d | %s' % (revno, text)
+            elif branch.has_revision(line_rev_id):
+                rev = branch.get_revision(line_rev_id)
+                date_str = time.strftime('%Y%m%d', time.gmtime(rev.timestamp + rev.timezone))
+                print '%8s | %s' % (date_str, text)
+            else:
+                print '%8.8s | %s' % (line_rev_id, text)
 
 
 
 if __name__ == '__main__':
-    from bzrlib.branch import find_branch
+    from bzrlib.branch import Branch
     from bzrlib.trace import enable_default_logging
 
     enable_default_logging()
-    b = find_branch(sys.argv[1])
+    b = Branch.open_containing(sys.argv[1])
     rp = b.relpath(sys.argv[1])
     tree = b.revision_tree(b.last_revision())
     file_id = tree.inventory.path2id(rp)

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-10-13 01:29:22 +0000
+++ bzrlib/builtins.py	2005-10-13 03:43:37 +0000
@@ -266,9 +266,9 @@
 
     See also the 'move' command, which moves files into a different
     directory without changing their name.
-
-    TODO: Some way to rename multiple files without invoking bzr for each
-    one?"""
+    """
+    # TODO: Some way to rename multiple files without invoking 
+    # bzr for each one?"""
     takes_args = ['from_name', 'to_name']
     
     def run(self, from_name, to_name):
@@ -440,11 +440,10 @@
 
 class cmd_renames(Command):
     """Show list of renamed files.
-
-    TODO: Option to show renames between two historical versions.
-
-    TODO: Only show renames under dir, rather than in the whole branch.
     """
+    # TODO: Option to show renames between two historical versions.
+
+    # TODO: Only show renames under dir, rather than in the whole branch.
     takes_args = ['dir?']
 
     def run(self, dir='.'):
@@ -568,26 +567,24 @@
     If files are listed, only the changes in those files are listed.
     Otherwise, all changes for the tree are listed.
 
-    TODO: Allow diff across branches.
-
-    TODO: Option to use external diff command; could be GNU diff, wdiff,
-          or a graphical diff.
-
-    TODO: Python difflib is not exactly the same as unidiff; should
-          either fix it up or prefer to use an external diff.
-
-    TODO: If a directory is given, diff everything under that.
-
-    TODO: Selected-file diff is inefficient and doesn't show you
-          deleted files.
-
-    TODO: This probably handles non-Unix newlines poorly.
-
     examples:
         bzr diff
         bzr diff -r1
         bzr diff -r1..2
     """
+    # TODO: Allow diff across branches.
+    # TODO: Option to use external diff command; could be GNU diff, wdiff,
+    #       or a graphical diff.
+
+    # TODO: Python difflib is not exactly the same as unidiff; should
+    #       either fix it up or prefer to use an external diff.
+
+    # TODO: If a directory is given, diff everything under that.
+
+    # TODO: Selected-file diff is inefficient and doesn't show you
+    #       deleted files.
+
+    # TODO: This probably handles non-Unix newlines poorly.
     
     takes_args = ['file*']
     takes_options = ['revision', 'diff-options']
@@ -624,19 +621,17 @@
 
 class cmd_deleted(Command):
     """List files deleted in the working tree.
-
-    TODO: Show files deleted since a previous revision, or between two revisions.
     """
+    # TODO: Show files deleted since a previous revision, or
+    # between two revisions.
+    # TODO: Much more efficient way to do this: read in new
+    # directories with readdir, rather than stating each one.  Same
+    # level of effort but possibly much less IO.  (Or possibly not,
+    # if the directories are very large...)
     def run(self, show_ids=False):
         b = Branch.open_containing('.')
         old = b.basis_tree()
         new = b.working_tree()
-
-        ## TODO: Much more efficient way to do this: read in new
-        ## directories with readdir, rather than stating each one.  Same
-        ## level of effort but possibly much less IO.  (Or possibly not,
-        ## if the directories are very large...)
-
         for path, ie in old.inventory.iter_entries():
             if not new.has_id(ie.file_id):
                 if show_ids:
@@ -788,9 +783,8 @@
 
 class cmd_ls(Command):
     """List files in a tree.
-
-    TODO: Take a revision or remote path and list that tree instead.
     """
+    # TODO: Take a revision or remote path and list that tree instead.
     hidden = True
     def run(self, revision=None, verbose=False):
         b = Branch.open_containing('.')
@@ -822,8 +816,9 @@
     To remove patterns from the ignore list, edit the .bzrignore file.
 
     If the pattern contains a slash, it is compared to the whole path
-    from the branch root.  Otherwise, it is comapred to only the last
-    component of the path.
+    from the branch root.  Otherwise, it is compared to only the last
+    component of the path.  To match a file only in the root directory,
+    prepend './'.
 
     Ignore patterns are case-insensitive on case-insensitive systems.
 
@@ -833,6 +828,7 @@
         bzr ignore ./Makefile
         bzr ignore '*.class'
     """
+    # TODO: Complain if the filename is absolute
     takes_args = ['name_pattern']
     
     def run(self, name_pattern):
@@ -985,19 +981,18 @@
     A selected-file commit may fail in some cases where the committed
     tree would be invalid, such as trying to commit a file in a
     newly-added directory that is not itself committed.
-
-    TODO: Run hooks on tree to-be-committed, and after commit.
-
-    TODO: Strict commit that fails if there are unknown or deleted files.
     """
+    # TODO: Run hooks on tree to-be-committed, and after commit.
+
+    # TODO: Strict commit that fails if there are unknown or deleted files.
+    # TODO: Give better message for -s, --summary, used by tla people
+
+    # XXX: verbose currently does nothing
+
     takes_args = ['selected*']
     takes_options = ['message', 'file', 'verbose', 'unchanged']
     aliases = ['ci', 'checkin']
 
-    # TODO: Give better message for -s, --summary, used by tla people
-
-    # XXX: verbose currently does nothing
-    
     def run(self, message=None, file=None, verbose=True, selected_list=None,
             unchanged=False):
         from bzrlib.errors import PointlessCommit, ConflictsInTree
@@ -1176,10 +1171,9 @@
 
 class cmd_find_merge_base(Command):
     """Find and print a base revision for merging two branches.
-
-    TODO: Options to specify revisions on either side, as if
-          merging only part of the history.
     """
+    # TODO: Options to specify revisions on either side, as if
+    #       merging only part of the history.
     takes_args = ['branch', 'other']
     hidden = True
     

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2005-10-12 07:28:41 +0000
+++ bzrlib/inventory.py	2005-10-13 03:43:37 +0000
@@ -397,6 +397,10 @@
         Note that this should be modified to be a noop on virtual trees
         as all entries created there are prepopulated.
         """
+        # TODO: Rather than running this manually, we should check the 
+        # working sha1 and other expensive properties when they're
+        # first requested, or preload them if they're already known
+        pass            # nothing to do by default
 
 
 class RootEntry(InventoryEntry):

=== modified file 'bzrlib/transport/http.py'
--- bzrlib/transport/http.py	2005-10-10 03:24:15 +0000
+++ bzrlib/transport/http.py	2005-10-10 06:21:37 +0000
@@ -145,8 +145,8 @@
         try:
             return get_url(self.abspath(relpath))
         except (BzrError, urllib2.URLError, IOError), e:
-            raise NoSuchFile(msg = "Error retrieving %s" 
-                             % self.abspath(relpath),
+            raise NoSuchFile(msg = "Error retrieving %s: %s" 
+                             % (self.abspath(relpath), str(e)),
                              orig_error=e)
 
     def get_partial(self, relpath, start, length=None):

=== modified file 'setup.py' (properties changed: +x to -x)
